import sys
import logging

from enum import StrEnum
from lyngdorf.mp60 import LyngdorfMP60Client

stdout_handler = logging.StreamHandler(stream=sys.stdout)

logging.basicConfig(level=logging.DEBUG, handlers=[stdout_handler])

class LyngdorfModel(StrEnum):
    MP_60 = "mp-60"
    
def create_client(model: LyngdorfModel, host: str):
    if (model == LyngdorfModel.MP_60):
        return LyngdorfMP60Client(host)
    raise NotImplementedError()


    


class LyngdorfError(Exception):
    """Define a Lyngdorf error."""


class LyngdorfInvalidValueError(LyngdorfError):
    """Define an error when an invalid value is passed to our API."""

    # pylint: disable=useless-super-delegation
    def __init__(self, message: str, *args, **kwargs) -> None:
        """Create a new instance."""
        super().__init__(message, *args, **kwargs)
